@@ -15,7 +15,7 @@
 import os
 
 from pyspark.sql.functions import pandas_udf, PandasUDFType
-from pyspark.sql.types import StringType
+from pyspark.sql.types import StringType, FloatType, MapType
 
 import pandas as pd
 import numpy as np
@@ -26,13 +26,24 @@ from astronet.preprocess import robust_scale
 from fink_utils.data.utils import format_data_as_snana
 
 from fink_science import __file__
-from fink_science.t2.utilities import get_lite_model, apply_selection_cuts_ztf
+from fink_science.t2.utilities import get_lite_model
+from fink_science.t2.utilities import apply_selection_cuts_ztf
+from fink_science.t2.utilities import extract_maxclass
+from fink_science.t2.utilities import T2_COLS
 
 from fink_science.tester import spark_unit_tests
 
 @pandas_udf(StringType(), PandasUDFType.SCALAR)
-def t2_max_prob(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist, model_name=None) -> pd.Series:
-    """ Return max prob from T2
+def maxclass(dic):
+    """ Extract t-he class with max probability
+    """
+    max_class_series = dic.apply(lambda x: extract_maxclass(x))
+    return max_class_series
+
+
+@pandas_udf(MapType(StringType(), FloatType()), PandasUDFType.SCALAR)
+def t2(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist, model_name=None) -> pd.Series:
+    """ Return vector of probabilities from T2
 
     Parameters
     ----------
@@ -50,7 +61,7 @@ def t2_max_prob(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist,
 
     Returns
     ----------
-    probabilities: 1D np.array of float
+    probabilities: dictionnary (class>str, prob>float)
         Probability between 0 (non-Ia) and 1 (Ia).
 
     Examples
@@ -86,15 +97,20 @@ def t2_max_prob(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist,
     # Perform the fit + classification (default t2 model)
     >>> args = ['candid', 'cjd', 'cfid', 'cmagpsf', 'csigmapsf']
     >>> args += [F.col('roid'), F.col('cdsxmatch'), F.col('candidate.jdstarthist')]
-    >>> df = df.withColumn('t2_maxclass', t2_max_prob(*args))
+    >>> df = df.withColumn('t2', t2(*args))
 
-    >>> df.filter(df['t2_maxclass'] == 'SNIa').count()
-    4
+    >>> df = df.withColumn('maxClass', maxclass('t2'))
+
+    >>> df.filter(df['maxClass'] == 'SNIa').count()
+    0
     """
+    default = {k: -1.0 for k in T2_COLS}
+    to_return = np.array([default for i in range(len(jd))])
+
     mask = apply_selection_cuts_ztf(magpsf, cdsxmatch, jd, jdstarthist, roid)
 
     if len(jd[mask]) == 0:
-        return pd.Series(np.array(['None'] * len(jd), dtype=np.str))
+        return pd.Series(to_return)
 
     ZTF_FILTER_MAP = {1: "ztfg", 2: "ztfr", 3: "ztfi"}
 
@@ -140,7 +156,7 @@ def t2_max_prob(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist,
 
         # Need all filters
         if len(np.unique(sub['filter'])) != 2:
-            vals.append('None')
+            vals.append(default)
             continue
 
         # one object at a time
@@ -156,37 +172,13 @@ def t2_max_prob(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist,
 
         y_preds = model.predict(X)
 
-        class_names = [
-            "mu-Lens-Single",
-            "TDE",
-            "EB",
-            "SNII",
-            "SNIax",
-            "Mira",
-            "SNIbc",
-            "KN",
-            "M-dwarf",
-            "SNIa-91bg",
-            "AGN",
-            "SNIa",
-            "RRL",
-            "SLSN-I",
-        ]
-
-        keys = class_names
         values = y_preds.tolist()
-        predictions = dict(zip(keys, values[0]))
+        predictions = dict(zip(T2_COLS, values[0]))
+        vals.append(predictions)
 
-        idx = np.where(np.array(list(predictions.values())) == np.max(list(predictions.values())))[0][0]
-        snia_val = list(predictions.keys())[idx]
-        vals.append(str(snia_val))
-
-    # Take only probabilities to be Ia
-    # to_return = np.zeros(len(jd), dtype=float)
-    to_return = np.array(['None'] * len(jd), dtype=np.str)
     to_return[mask] = vals
 
-    # return probabilities to be Ia
+    # return vector of probabilities
     return pd.Series(to_return)
 
 
